What is it about?
===================

It is a PyQt5 interface for multithreaded periodical data acquisition and communication with an I/O device.

It will manage the creation and handling of the threads, workers and signals for you, reducing it to just a few simple method calls of a QDeviceIO class instance to get set up and going.

Stable beta. Documentation will be added next. Within a month (at July 2020) I expect a proper release.
